@@ -1,7 +1,4 @@
 # coding: utf-8
-from __future__ import division, unicode_literals, absolute_import
-
-import bisect as bs
 
 """
 Additional bisect functions. Taken from
@@ -12,6 +9,8 @@ The functions show how to transform them into the standard lookups for sorted
 lists.
 """
 
+import bisect as bs
+
 __author__ = 'Matteo Giantomassi'
 __copyright__ = 'Copyright 2013, The Materials Virtual Lab'
 __version__ = '0.1'
@@ -25,35 +24,41 @@ def index(a, x, atol=None):
     i = bs.bisect_left(a, x)
     if i != len(a):
         if atol is None:
-            if a[i] == x: return i
+            if a[i] == x:
+                return i
         else:
-            if abs(a[i] - x) < atol: return i
+            if abs(a[i] - x) < atol:
+                return i
     raise ValueError
 
 
 def find_lt(a, x):
     """Find rightmost value less than x."""
     i = bs.bisect_left(a, x)
-    if i: return i - 1
+    if i:
+        return i - 1
     raise ValueError
 
 
 def find_le(a, x):
     """Find rightmost value less than or equal to x."""
     i = bs.bisect_right(a, x)
-    if i: return i - 1
+    if i:
+        return i - 1
     raise ValueError
 
 
 def find_gt(a, x):
     """Find leftmost value greater than x."""
     i = bs.bisect_right(a, x)
-    if i != len(a): return i
+    if i != len(a):
+        return i
     raise ValueError
 
 
 def find_ge(a, x):
     """Find leftmost item greater than or equal to x."""
     i = bs.bisect_left(a, x)
-    if i != len(a): return i
+    if i != len(a):
+        return i
     raise ValueError
