@@ -15,7 +15,7 @@ import functools
 logger = logging.getLogger(__name__)
 
 
-def deprecated(replacement=None, message=None):
+def deprecated(replacement=None, message=None, category=FutureWarning):
     """
     Decorator to mark classes or functions as deprecated,
     with a possible replacement.
@@ -23,6 +23,12 @@ def deprecated(replacement=None, message=None):
     Args:
         replacement (callable): A replacement class or method.
         message (str): A warning message to be displayed.
+        category (Warning): Choose the category of the warning to issue. Defaults
+            to FutureWarning. Another choice can be DeprecationWarning. NOte that
+            FutureWarning is meant for end users and is always shown unless silenced.
+            DeprecationWarning is meant for developers and is never shown unless
+            python is run in developmental mode or the filter is changed. Make
+            the choice accordingly.
 
     Returns:
         Original function, but with a warning to use the updated class.
@@ -41,7 +47,7 @@ def deprecated(replacement=None, message=None):
                 msg += "; use %s in %s instead." % (r.__name__, r.__module__)
             if message is not None:
                 msg += "\n" + message
-            warnings.warn(msg, FutureWarning, stacklevel=2)
+            warnings.warn(msg, category=category, stacklevel=2)
             return old(*args, **kwargs)
 
         return wrapped
