@@ -3,14 +3,12 @@
 This module provides support for Unix shell-style wildcards
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import fnmatch
 
 from monty.string import list_strings
 
 
-class WildCard(object):
+class WildCard:
     """
     This object provides an easy-to-use interface for filename matching with
     shell patterns (fnmatch).
