@@ -1,32 +1,23 @@
 # coding: utf-8
 """
-#TODO: Write module doc.
+Helpful regex based functions. E.g., grepping.
 """
 
-from __future__ import division, unicode_literals, absolute_import
-
 import re
-from monty.io import zopen, reverse_readfile
 import collections
 
-
-__author__ = 'Shyue Ping Ong'
-__copyright__ = 'Copyright 2013, The Materials Virtual Lab'
-__version__ = '0.1'
-__maintainer__ = 'Shyue Ping Ong'
-__email__ = 'ongsp@ucsd.edu'
-__date__ = '6/2/15'
+from monty.io import zopen, reverse_readfile
 
 
 def regrep(filename, patterns, reverse=False, terminate_on_match=False,
            postprocess=str):
-    """
+    r"""
     A powerful regular expression version of grep.
 
     Args:
         filename (str): Filename to grep.
         patterns (dict): A dict of patterns, e.g.,
-            {"energy": "energy\(sigma->0\)\s+=\s+([\d\-\.]+)"}.
+            {"energy": r"energy\\(sigma->0\\)\\s+=\\s+([\\d\\-\\.]+)"}.
         reverse (bool): Read files in reverse. Defaults to false. Useful for
             large files, especially when used with terminate_on_match.
         terminate_on_match (bool): Whether to terminate when there is at
@@ -57,6 +48,6 @@ def regrep(filename, patterns, reverse=False, terminate_on_match=False,
     try:
         # Try to close open file handle. Pass if it is a generator.
         gen.close()
-    except:
+    except Exception:
         pass
     return matches
